@@ -25,16 +25,16 @@ void SimOneMVN_mxIW(double *nu, double *Lbdinvhlf, double *f1f2, int *pd,
   mxnreps=0;
   for(l=0;l<N;l++) if(mxnreps < *(pnreps+l)) mxnreps = *(pnreps+l);
 
-  lbuff         = (int   *)S_alloc(        1,sizeof(int));
+  lbuff         = (int   *)Calloc(        1,int);
 
-  df            = (double *)S_alloc(        1, sizeof(double));
-  pW            = (double *)S_alloc(       d2, sizeof(double));
-  xbuff         = (double *)S_alloc(        d, sizeof(double));
-  SgmHlf        = (double *)S_alloc(       d2, sizeof(double));
-  Y             = (double *)S_alloc(mxnreps*d, sizeof(double));
-  Sigma         = (double *)S_alloc(       d2, sizeof(double));
-  SigInv        = (double *)S_alloc(       d2, sizeof(double));
-  sig           = (double *)S_alloc(        d, sizeof(double));
+  df            = (double *)Calloc(        1, double);
+  pW            = (double *)Calloc(       d2, double);
+  xbuff         = (double *)Calloc(        d, double);
+  SgmHlf        = (double *)Calloc(       d2, double);
+  Y             = (double *)Calloc(mxnreps*d, double);
+  Sigma         = (double *)Calloc(       d2, double);
+  SigInv        = (double *)Calloc(       d2, double);
+  sig           = (double *)Calloc(        d, double);
 
   f_1 = *f1f2;
   f_2 = *(f1f2+1);
@@ -104,4 +104,15 @@ void SimOneMVN_mxIW(double *nu, double *Lbdinvhlf, double *f1f2, int *pd,
     for(i=0;i<(nreps*d);i++) *(YY + mxnreps*d*l + i) = *(Y+i);
   }
   PutRNGstate();
+
+  Free(lbuff);
+  Free(df);
+  Free(pW);
+  Free(xbuff);
+  Free(SgmHlf);
+  Free(Y);
+  Free(Sigma);
+  Free(SigInv);
+  Free(sig);
+
 }
